Learn R Programming

animalEKF (version 1.3)

animalEKF-package: tools:::Rd_package_title("animalEKF")

Description

Synthetic generation of 1-D and 2-D correlated random walks (CRWs) for animal movement with behavioral switching, and particle filter estimation of movement parameters from observed trajectories using Extended Kalman Filter (EKF) model. See Ackerman (2018)
https://digital.library.temple.edu/digital/collection/p245801coll10/id/499150.

Arguments

References

Ackerman, Samuel. "A Probabilistic Characterization of Shark Movement Using Location Tracking Data." Temple University doctoral thesis, 2018. https://digital.library.temple.edu/digital/collection/p245801coll10/id/499150

Carvalho, Carlos M., Johannes, Michael S., Lopes, Hedibert F., and Nicholas G. Polson. "Particle Learning and Smoothing." Statistical Science, 2010.

Espinoza, Mario, Farrugia, Thomas J., Lowe, Christopher G. "Habitat Use, Movements and Site Fidelity of the Gray Smooth-Hound Shark in a Newly Restored Southern California Estuary." Journal of Experimental Marine Biology and Ecology, 2011.