Learn R Programming

animalEKF (version 1.3)

bc_longlat_map_img_ras: Raster image of Bolsa Chica for use with shark_vis_longlat

Description

Raster image of Bolsa Chica for use with shark_vis_longlat

Usage

data("bc_longlat_map_img_ras")

Arguments

Format

The format is: 'raster' chr [1:640, 1:640] "#A3CCFFFF" "#A3CCFFFF" "#A3CCFFFF" ...

Examples

Run this code
data(bc_longlat_map_img_ras)

Run the code above in your browser using DataLab